__version__ = "1.0.4"


class APP(object):
    name = "colorize"
    program = 'python -m colorize'
    version = __version__
    description = "Command line utility to colorize other commands output"
